# GeoFinder 
GeoFinder validates all the place names in a GEDCOM geneology file and adds their latitude/longitude.


## Overview  
GeoFinder reads in a GEDCOM geneology file and looks up each place (PLAC entry) in a gazetteer using location data from geonames.org.  It is used to help fix place name errors in large gedcom files.  It also fills in the latitude and longitude for any places that are found.  
   
[See User Guide Wiki for details](https://github.com/corb555/GeoFinder/wiki/User-Guide)

